def find_possible_placements(field, token):
	possibilities = []
	i = 0
	j = 0
	# bounds check implicit through trimmed token
	while token.col_count+i <= field.col_count:
		while token.row_count+j <= field.row_count:
			if is_possible_placements((i,j), field, token):
				possibilities.append((i,j))
			++j
		++i
	return possibilities

def is_possible_placements(placement, field, token):
	opponent = has_no_opponent_overlap(placement, field, token)
	player = has_exactly_one_player_overlap(placement, field, token)
	return (opponent and player)

def has_no_opponent_overlap(placement, field, token):
	return (get_overlap_count(placement, field.opponent, token) == 0)

def has_exactly_one_player_overlap(placement, field, token):
	return (get_overlap_count(placement, field.player, token) == 1)

def get_overlap_count(placement, shape, token):
	overlap_count = 0
	for token_y in token.content:
		for token_x in token.content[token_y]:
			if shape[token_y+placement[0]][token_x+placement[1]]:
				++overlap_count
	return overlap_count
	


import field.py
import parse.py
import token.py
import placement.py

def parse_field(player_number, field):
	(row_count, column_count) = parse.parse_field_meta(input())
	field.update_dimensions(row_count, column_count)
	_ = input() # drop column number row
	for row_index in range(0:field.row_count):
		row_as_string = parse.split_field_input_line(input())[1]
		(_, player_one, player_two) = parse.parse_field_line(row_as_string, row_index)
		if player_number = 1:
			field.player.update_content(player_one)
			field.opponent.update_content(player_two)
		else:
			field.player.update_content(player_two)
			field.opponent.update_content(player_one)

def parse_token(token):
	(row_count, column_count) = parse.parse_field_meta(input())
	token.update_dimensions(row_count, column_count)
	for row_index in range(0:token.row_count):
		(token_res, _, _) = parse.parse_field_line(input(), row_index)
		token.content.update_content(token_res)
	token.trim()

def parse_input(player_number, field, token):
	parse_field(player_number, field)
	return parse_token(token)

def place_token(field, token):
	possibilites = placement.find_possible_placements(field, token)
	could_place = (len(possibilites) > 0)
	return (could_place, possibilites[0][0], possibilites[0][1])

def main() -> None:
	try:
		player_number = parse.parse_player(input())[0]
		field = field.Field()
		token = token.Token()
		could_place = True
		
		while could_place:
			parse_input(player_number, field, token)
			(could_place, x, y) = place_token(field, token)
			if could_place:
				print(x, y)
	except Exception as e:
		print(e)
		exit(1)

if __name__ == "__main__":
	main()



from enum import Enum
import shape.py

class Cell_State(Enum):
	EMPTY = '.'
	TOKEN = '*'
	PLAYER_ONE_OLD = 'O'
	PLAYER_ONE_NEW = 'o'
	PLAYER_TWO_OLD = 'X'
	PLAYER_TWO_NEW = 'x'

class Field:
	def __init__(self):
		self.row_count = 0
		self.column_count = 0
		self.player = shape.Shape()
		self.opponent = shape.Shape()
	
	def update_dimensions(self, row_count, column_count):
		self.row_count = row_count
		self.column_count = column_count
		self.player.update_dimensions(row_count, column_count)
		self.opponent.update_dimensions(row_count, column_count)
	


import re
import field.py

def parse_player(input):
	match = re.match(r"$$$ exec p(\d{1}) : [([a-zA-Z]+)]", input)
	if not match:
		raise Exception('Player input string could not be parsed')
	if not match.group(1):
		raise Exception('Player number could not be parsed from player input')
	if not match.group(2):
		raise Exception('Player name could not be parsed from player input')
	return (match.group(1), match.group(2))

def parse_field_meta(input):
	match = re.match(r"[Plateau|Piece] (\d+) (\d+):", input)
	if not match:
		raise Exception('Field input string could not be parsed')
	if not match.group(1):
		raise Exception('Field row count could not be parsed from meta input')
	if not match.group(2):
		raise Exception('Field column count could not be parsed from meta input')
	return (match.group(1), match.group(2))

def split_field_input_line(input):
	match = re.match(r"(\d+{3}) (.+)", input)
	if not match:
		raise Exception('Field row input string could not be parsed')
	if not match.group(1):
		raise Exception('Field row number could not be parsed from row input')
	if not match.group(2):
		raise Exception('Field row contents could not be parsed from row input')
	return (match.group(1), match.group(2))

def parse_field_line(line, row_index):
	col_index = 0
	player_one = []
	player_two = []
	token = []
	while col_index < len(line):
		char = line[col_index]
		match char:
			case field.Cell_State.EMPTY:
				# Nothing to do
			case field.Cell_State.TOKEN:
				token.append((row_index, col_index))
			case field.Cell_State.PLAYER_ONE_OLD:
				player_one.append((row_index, col_index))
			case field.Cell_State.PLAYER_ONE_NEW:
				player_one.append((row_index, col_index))
			case field.Cell_State.PLAYER_TWO_OLD:
				player_two.append((row_index, col_index))
			case field.Cell_State.PLAYER_TWO_NEW:
				player_two.append((row_index, col_index))
			case _:
				raise Exception('Cell contains invalid character')
		++col_index
	return ((token, player_one, player_two))


class Shape:
	def __init__(self):
		self.content = []
	
	def update_dimensions(self, row_count, column_count):
		for row_index in range(0:row_count):
			if not row_index < len(self.content):
				self.content[row_index] = []
			for col_index in range(0:column_count):
				if not col_index < len(self.content[row_index]):
					self.content[row_index][col_index] = False
		while row_count < len(self.content):
			self.content.pop()
	
	def update_content(self, coordinate_list):
		i = 0
		while i < len(coordinate_list):
			self.content[coordinate_list[i][0]][coordinate_list[i][1]] = True
			++i
	
	def get_max_set_col(self):
		i = 0
		j = 0
		max = 0
		while i < len(self.content):
			while j < len(self.content[i]):
				if self.content[i][j] and j  > max:
					max = j
		return max
	
	def get_max_set_row(self):
		i = 0
		j = 0
		max = 0
		while i < len(self.content):
			while j < len(self.content[i]):
				if self.content[i][j] and i  > max:
					max = i
		return max


import shape.py

class Token:
	def __init__(self, row_count, column_count):
		self.row_count = 0
		self.column_count = 0
		self.content = shape.Shape()
	
	def update_dimensions(self, row_count, column_count):
		self.row_count = row_count
		self.column_count = column_count
		self.content.update_dimensions(row_count, column_count)
	
	def trim(self):
		max_col = self.content.get_max_set_col()
		max_row = self.content.get_max_set_row()
		self.content.update_dimensions(max_row, max_col)
